#
# spec file for package python (Version 2.6.2)
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           python
BuildRequires:  db-devel gdbm-devel gmp-devel libbz2-devel libopenssl-devel ncurses-devel readline-devel sqlite-devel tk-devel xorg-x11-devel
%if %suse_version >= 1030
BuildRequires:  fdupes
%endif
#Requires:       openssl >= 0.9.8e
Url:            http://www.python.org/
License:        MIT License (or similar)
Group:          Development/Languages/Python
AutoReqProv:    on
# bug437293
%ifarch ppc64
Obsoletes:      python-64bit
%endif
#
Obsoletes:      python-nothreads python21 python-elementtree python-sqlite
Summary:        Python Interpreter
Version:        2.6.2
Release:        6.5.1
Requires:       python-base = %{version}
%define       tarname        Python-%{version}
Source0:        %{tarname}.tar.bz2
Source6:        README.SUSE
Source8:        pythonstart
Source9:        python.sh
Source10:       python.csh
#Source11:       testfiles.tar.bz2
# issues with copyrighted Unicode testing files
Patch01:        Python-2.3.3-dirs.patch
Patch21:        Python-2.6.2-multilib.patch
Patch23:        python-2.6b3-ssl-compat.patch
Patch25:        python-2.6b1-canonicalize2.patch
Patch30:        python-2.5.1-sqlite.patch
Patch31:        python-2.5.2-fwrapv.patch
Patch35:        python-2.5.2-configure.patch
Patch38:        python-2.6b3-curses-panel.patch
Patch39:        python-2.6.2-ssl_handshake_timeout.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%define         python_version    %(echo %{version} | head -c 3)
%define         idle_name         idle
Provides:       %{name} = %{python_version}

%description
Python is an interpreted, object-oriented programming language, and is
often compared to Tcl, Perl, Scheme, or Java.  You can find an overview
of Python in the documentation and tutorials included in the python-doc
(HTML) or python-doc-pdf (PDF) packages.

If you want to install third party modules using distutils, you need to
install python-devel package.



Authors:
--------
    Guido van Rossum <guido@python.org>

%package idle
License:        Python License ..
Requires:       python-base = %{version} python-tk
Summary:        An Integrated Development Environment for Python
Group:          Development/Languages/Python
AutoReqProv:    on

%description idle
IDLE is a Tkinter based integrated development environment for Python.
It features a multi-window text editor with multiple undo, Python
colorizing, and many other things, as well as a Python shell window and
a debugger.



Authors:
--------
    Guido van Rossum <guido@python.org>

%package demo
License:        Python License ..
Provides:       pyth_dmo
Obsoletes:      pyth_dmo
Requires:       python-base = %{version}
Summary:        Python Demonstration Scripts
Group:          Development/Languages/Python
AutoReqProv:    on

%description demo
Various demonstrations of what you can do with Python and a number of
programs that are useful for building or extending Python.



Authors:
--------
    Guido van Rossum <guido@python.org>

%package tk
License:        Python License ..
Provides:       pyth_tk python_tkinter_lib pyth_tkl python-tkinter
#%ifarch %ix86
#Provides:       _tkinter.so
#%endif
Obsoletes:      pyth_tk pyth_tkl python-tkinter
Requires:       python-base = %{version}
Summary:        TkInter - Python Tk Interface
Group:          Development/Libraries/Python
AutoReqProv:    on

%description tk
Python interface to Tk. Tk is the GUI toolkit that comes with Tcl. The
"xrpm" package uses this Python interface.



Authors:
--------
    Guido van Rossum <guido@python.org>

%package curses
License:        Python License ..
Requires:       python-base = %{version}
Obsoletes:      pyth_cur
Provides:       pyth_cur
Summary:        Python Interface to the (N)Curses Library
Group:          Development/Libraries/Python
AutoReqProv:    on

%description curses
An easy to use interface to the (n)curses CUI library. CUI stands for
Console User Interface.



Authors:
--------
    Guido van Rossum <guido@python.org>

%package gdbm
License:        MIT License (or similar)
Requires:       python-base = %{version}
Obsoletes:      pygdmod
Provides:       pygdmod
Summary:        Python Interface to the GDBM Library
Group:          Development/Libraries/Python
AutoReqProv:    on

%description gdbm
An easy to use interface for GDBM databases. GDBM is the GNU
implementation of the standard Unix DBM databases.



Authors:
--------
    Guido van Rossum <guido@python.org>

%prep
#%%setup -q -n %{tarname} -a11
%setup -q -n %{tarname}
# remove expat
rm -r Modules/expat
rm Modules/pyexpat.c
# patching
%patch01
%patch21 -p1
%patch23
%patch25
%patch30
%patch31
#%if 0%{?suse_version}
#%endif
%patch35
%if %suse_version > 1100
%patch38
%endif
%patch39
# some cleanup
find . -name .cvsignore -type f -print0 | xargs -0 rm -f
find . -name CVS -type d -print0 | xargs -0 rm -rf

%build
########################################
# disable as-needed to fix build
########################################
export SUSE_ASNEEDED=0
########################################
# use rpm_opt_flags
########################################
export OPT="$RPM_OPT_FLAGS"
########################################
# regenerate
########################################
autoreconf -f -i . # Modules/_ctypes/libffi
# prevent make from trying to rebuild asdl stuff, which requires existing
# python installation
touch Parser/asdl* Python/Python-ast.c Include/Python-ast.h
########################################
# configure
########################################
./configure \
    --prefix=%{_prefix} \
    --libdir=%{_libdir} \
    --mandir=%{_mandir} \
    --docdir=%{_docdir}/python \
    --enable-ipv6 \
    --with-fpectl \
    --enable-shared \
    --enable-unicode=ucs4
########################################
# compile
########################################
make %{?jobs:-j%jobs} DESTDIR=$RPM_BUILD_ROOT

%check
# on hppa, the threading of glibc is quite broken. The tests just stop
# at some point, and the machine does not build anything more until a
# timeout several hours later. 
%ifnarch hppa %arm
# Limit virtual memory to avoid spurious failures
if test $(ulimit -v) = unlimited || test $(ulimit -v) -gt 10000000; then
  ulimit -v 10000000 || :
fi
LIST="test_urllib test_ssl test_hashlib test_hmac test_urllib2_localnet test_unicodedata test_tarfile test_sqlite test_tcl test_anydbm test_dumbdbm test_gdbm test_whichdb"
make test TESTOPTS="$LIST"
%endif

%install
# replace rest of /usr/local/bin/python or /usr/bin/python2.x with /usr/bin/python
find . -wholename "./Parser" -prune -o -name '*.py' -type f -print0 | xargs -0 grep -lE '^#! *(/usr/.*bin/(env +)?)?python' | xargs sed -r -i -e '1s@^#![[:space:]]*(/usr/(local/)?bin/(env +)?)?python([0-9]+\.[0-9]+)?@#!/usr/bin/python@'
# the grep inbetween makes it much faster
########################################
# install it
########################################
make \
    OPT="$RPM_OPT_FLAGS -fPIC" \
    DESTDIR=$RPM_BUILD_ROOT \
    install
########################################
# some cleanups
########################################
# remove hard links and replace them with symlinks
for dir in bin include %{_lib} ; do
    rm -f $RPM_BUILD_ROOT/%{_prefix}/$dir/python
    ln -s python%{python_version} $RPM_BUILD_ROOT/%{_prefix}/$dir/python
done
# kill imageop.so, it's insecure
rm -f $RPM_BUILD_ROOT/%{_libdir}/python%{python_version}/lib-dynload/imageop.so
#cleanup for -base
rm $RPM_BUILD_ROOT%{_bindir}/python{,%{python_version}}
rm $RPM_BUILD_ROOT%{_bindir}/smtpd.py
rm $RPM_BUILD_ROOT%{_bindir}/pydoc
rm $RPM_BUILD_ROOT%{_bindir}/2to3
rm $RPM_BUILD_ROOT%{_mandir}/man1/python.1*
rm $RPM_BUILD_ROOT%{_libdir}/libpython*.so.*
rm $RPM_BUILD_ROOT%{_libdir}/python
find $RPM_BUILD_ROOT%{_libdir}/python%{python_version} -maxdepth 1 ! \( -name "ssl.py" \) -exec rm {} ";"
rm $RPM_BUILD_ROOT%{_bindir}/python%{python_version}-config
rm $RPM_BUILD_ROOT%{_bindir}/python-config
rm -r $RPM_BUILD_ROOT%{_includedir}/python
rm -r $RPM_BUILD_ROOT%{_includedir}/python%{python_version}
rm -r $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/compiler
rm -r $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/config
rm -r $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/ctypes
rm -r $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/distutils
rm -r $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/email
rm -r $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/encodings
rm -r $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/hotshot
rm -r $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/json
rm -r $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib2to3
rm -r $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/logging
rm -r $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/multiprocessing
rm -r $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/plat-*
rm -r $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/test
rm -r $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/wsgiref
rm -r $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/xml
rm $RPM_BUILD_ROOT%{_libdir}/libpython%{python_version}.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/site-packages/README
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/_bisect.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/_bytesio.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/_csv.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/_collections.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/_ctypes.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/_ctypes_test.so
#rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/_elementtree.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/_fileio.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/_functools.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/_heapq.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/_hotshot.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/_json.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/_locale.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/_lsprof.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/_multiprocessing.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/_random.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/_socket.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/_struct.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/_testcapi.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/_weakref.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/array.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/binascii.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/bz2.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/cPickle.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/cStringIO.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/cmath.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/crypt.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/datetime.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/fcntl.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/future_builtins.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/grp.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/itertools.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/linuxaudiodev.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/math.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/mmap.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/nis.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/operator.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/ossaudiodev.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/parser.so
#rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/pyexpat.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/resource.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/select.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/spwd.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/strop.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/syslog.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/termios.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/time.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/unicodedata.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/zlib.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/_codecs*.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/_multibytecodec.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/audioop.so
rm -f $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/dl.so
rm $RPM_BUILD_ROOT%{_libdir}/python%{python_version}/lib-dynload/Python-%{version}-py%{python_version}.egg-info
%if %suse_version >= 1030
# replace duplicate .pyo/.pyc with hardlinks
%fdupes $RPM_BUILD_ROOT/%{_libdir}/python%{python_version}
%endif
########################################
# documentation
########################################
export PDOCS=${RPM_BUILD_ROOT}%{_docdir}/%{name}
install -d -m 755 $PDOCS
install -c -m 644 %{SOURCE6}                        $PDOCS/
install -c -m 644 LICENSE                           $PDOCS/
install -c -m 644 README                            $PDOCS/
########################################
# tools and demos
########################################
find Tools/ Demo/ -type d \( -regex ".*/.cvsignore" \) -exec rm -f \{\} \;
for x in `find Tools/ Demo/ \( -not -name Makefile \) -print | sort` ; do
  test -d $x && ( install -c -m 755 -d $PDOCS/$x ) \
             || ( install -c -m 644 $x $PDOCS/$x )
done
########################################
# idle
########################################
# move idle config into /etc
install -d -m755 ${RPM_BUILD_ROOT}/etc/%{idle_name}
( 
    cd ${RPM_BUILD_ROOT}/%{_libdir}/python%{python_version}/idlelib/
    for file in *.def ; do
        mv $file ${RPM_BUILD_ROOT}/etc/%{idle_name}/
        ln -sf /etc/%{idle_name}/$file  ${RPM_BUILD_ROOT}/%{_libdir}/python%{python_version}/idlelib/
    done
)
########################################
# startup script
########################################
install -m 644 %{S:8} $RPM_BUILD_ROOT/etc
install -d -m 755 $RPM_BUILD_ROOT/etc/profile.d
install -m 644 %{S:9} %{S:10} $RPM_BUILD_ROOT/etc/profile.d

%clean
rm -rf $RPM_BUILD_ROOT

%post
%{run_ldconfig}

%postun
%{run_ldconfig}

%files idle
%defattr(644, root, root, 755)
%dir /etc/%{idle_name}
%config /etc/%{idle_name}/*
%doc Lib/idlelib/NEWS.txt
%doc Lib/idlelib/README.txt
%doc Lib/idlelib/TODO.txt
%doc Lib/idlelib/extend.txt
%doc Lib/idlelib/ChangeLog
%{_libdir}/python%{python_version}/idlelib
%attr(755, root, root) %{_bindir}/%{idle_name}

%files demo
%defattr(644, root, root, 755)
%doc %{_docdir}/%{name}/Demo
%doc %{_docdir}/%{name}/Tools

%files tk
%defattr(644, root, root, 755)
%{_libdir}/python%{python_version}/lib-tk/
%{_libdir}/python%{python_version}/lib-dynload/_tkinter.so

%files curses
%defattr(644, root, root, 755)
%{_libdir}/python%{python_version}/curses
%{_libdir}/python%{python_version}/lib-dynload/_curses.so
%{_libdir}/python%{python_version}/lib-dynload/_curses_panel.so

%files gdbm
%defattr(644, root, root, 755)
%{_libdir}/python%{python_version}/lib-dynload/gdbm.so
%{_libdir}/python%{python_version}/lib-dynload/dbm.so

%files
%defattr(644, root, root, 755)
%dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/README
%doc %{_docdir}/%{name}/LICENSE
%doc %{_docdir}/%{name}/README.SUSE
%config /etc/pythonstart
%config /etc/profile.d/python.*
%dir %{_libdir}/python%{python_version}
%{_libdir}/python%{python_version}/ssl.py*
%{_libdir}/python%{python_version}/bsddb
%{_libdir}/python%{python_version}/sqlite3
%dir %{_libdir}/python%{python_version}/lib-dynload
%{_libdir}/python%{python_version}/lib-dynload/_bsddb.so
%{_libdir}/python%{python_version}/lib-dynload/_hashlib.so
%{_libdir}/python%{python_version}/lib-dynload/_sqlite3.so
%{_libdir}/python%{python_version}/lib-dynload/_ssl.so
%{_libdir}/python%{python_version}/lib-dynload/readline.so

%changelog
* Mon Mar 29 2010 matejcik@suse.cz
- removed expat-related source pieces to ensure that they don't
  sneak into release
* Tue Sep  8 2009 max@suse.de
- removed blt from BuildRequires so that it can be dropped.
* Fri Sep  4 2009 matejcik@suse.cz
- added patch for potential SSL hangup during handshake (bnc#525295)
* Wed Jul 29 2009 matejcik@suse.cz
- renamed multilib patch to reflect the changes
* Thu Jul 16 2009 coolo@novell.com
- disable as-needed to fix build
* Mon Apr 27 2009 matejcik@suse.cz
- update to 2.6.2
  * bugfix-only release for 2.6 series
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Mon Dec 15 2008 matejcik@suse.cz
- reenabled bsddb module, so that dependent packages can build
  ( bnc#441088 )
* Thu Oct  9 2008 matejcik@suse.cz
- update to 2.6 (version name is 2.6.0 to prevent upgrade problems)
- don't run the whole test suite, only run tests for
  newly built modules
- provide %%name = 2.6
* Fri Sep 19 2008 matejcik@suse.cz
- moved testsuite to %%check section
- update to 2.6rc2, removing the last remaining security patch
- included fix for socket.ssl() behavior regression, fixing
  bnc#426563
* Tue Sep 16 2008 matejcik@suse.cz
- moved python-xml to subpackage of python-base
- moved dbm.so to gdbm subpackage
- moved ssl.py and sqlite3 module to this
* Mon Sep 15 2008 matejcik@suse.cz
- update to 2.6rc1 - bugfix-only pre-stable release
* Fri Sep 12 2008 matejcik@suse.cz
- split package, as per fate#305065
- moved python-devel to be a subpackage of python-base
- minor fixes & packaging cleanups
* Wed Sep 10 2008 matejcik@suse.cz
- fixed misapplied ssl-compat patch (caused segfaults when
  opening SSL connections, bnc#425138 )
* Wed Sep  3 2008 matejcik@suse.cz
- updated to 2.6beta3 from BETA dist, summary of changes follows:
  * patches update/cleanup
  * removed failing tests (test_unicode, test_urllib2), those will
    be reworked later to not fail
  * fixed ncurses/panel.h include
  * removed most security fixes, as they are already included in
    this version
  * removed imageop/rgbimg
    (reasons: they only work in 32bit environment anyway, are
    deprecated by upstream and have inherent security problems)
  * fixed pythonstart script to trim history after 10000 lines
    (bnc#399190)
- 2.6beta3 is mostly stable release of the 2.6 series,
  package will be updated to 2.6 final as soon as it comes out
  (in the beginning of October)
* Wed Jul 30 2008 matejcik@suse.cz
- security fixes for issues mentioned in bnc#406051:
  * CVE-2008-2315 - multiple integer overflows in basic types
  * CVE-2008-2316 - partial hashing of huge data with hashlib
  * CVE-2008-3142 - multiple buffer oveflows in unicode processing
  * CVE-2008-3144 - possible integer over/underflow in mysnprintf
  * buffer overflows in expandtabs() method (afaik no CVE assigned)
- also mentioned CVE-2008-3143 is already fixed in python 2.5.2
* Mon Jun 30 2008 schwab@suse.de
- Work around autoheader bug.
* Fri Jun 13 2008 schwab@suse.de
- Fix configure script.
* Thu Apr 24 2008 matejcik@suse.cz
- proper path for html documentation from python-doc,
  help text mentioning python-doc package in pydoc
  (bnc#380942)
* Wed Apr 16 2008 matejcik@suse.cz
- PyString_FromStringAndSize now checks size parameter
  (bnc#379534, CVE-2008-1721)
* Tue Apr 15 2008 adrian@suse.de
- disable DNS lookup test when running in build service.
  The XEN build hosts have no network.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Mon Apr  7 2008 schwab@suse.de
- Limit virtual memory to avoid spurious testsuite failures.
* Mon Mar 10 2008 matejcik@suse.cz
- bnc#367853 turned out to be invalid, upstream is already on to
  the real problem
- forcing -fwrapv to compiler flags until upstream has a solution
* Wed Feb 27 2008 matejcik@suse.cz
- update to 2.5.2
  - bugfix-only release, over 100 bugs fixed
- removed hppa patch (already included)
- disabled test_str until gcc issue bnc#367853 is resolved
* Tue Nov 13 2007 matejcik@suse.cz
- patched a bug in sqlite module that would cause segfault on
  call to executescript()
  - > TODO return and improve the patch
* Mon Sep  3 2007 matejcik@suse.cz
- replaced fdupes oneliner with %%fdupes macro
- added /usr/bin/python2 symlink (#307097)
- obsoletes python-elementtree and python-sqlite (#301182)
  (obsoletes, but doesn't provide - the modules that obsolete those
  packages are renamed and dependent packages need to be changed)
* Fri Aug 24 2007 bg@suse.de
- fix build on hppa
* Fri Aug  3 2007 jmatejek@suse.cz
- replaced duplicate files with hardlinks
* Fri Jul 27 2007 jmatejek@suse.cz
- removed emacs python-mode and dependency on emacs
* Fri Jun  8 2007 jmatejek@suse.cz
- revisited & explained failing tests
- applied EINTR recovery patch (#278622)
- experimental replacement of shebang strings,
  removing dependency on /usr/bin/env
* Thu May 24 2007 jmatejek@suse.cz
- update to 2.5.1
  - bugfix only release, over 150 bugs fixed
  - fixes off-by-one memory leak in _localemodule.c
    (#276889, CVE-2007-2052)
- unnecessary patches removed, minor build cleanup
- warns when attempting to use https proxy (#214983)
* Tue May 22 2007 ro@suse.de
- make setup.py accept db-4.5
* Thu Mar 29 2007 aj@suse.de
- Add ncurses-devel to BuildRequires.
* Sat Mar 24 2007 aj@suse.de
- Add libbz2-devel to BuildRequires.
* Fri Mar 23 2007 rguenther@suse.de
- add gdbm-devel BuildRequires
* Mon Jan  8 2007 cthiel@suse.de
- fix sqlite3 support (#228733)
* Tue Sep 19 2006 jmatejek@suse.cz
- update to 2.5 final, going into STABLE dist
- issue with lib/python/config is not caused by dirs patch
* Wed Sep 13 2006 jmatejek@suse.cz
- update to 2.5c2
  - 2.5 final is expected next week
- removed testfiles.tar.bz2 from package due to copyright issues
  (see #204867). Reminder: enable urlfetch or put it back (or both,
  using Nosource)
* Tue Sep  5 2006 jmatejek@suse.cz
- update to 2.5c1
- many new features, see http://www.python.org/dev/peps/pep-0356/
- 64bit indices issue will require changes of modules, see
  http://www.python.org/dev/peps/pep-0353/ for transition guidelines
- non-backwards-compatible changes, see
  http://docs.python.org/dev/whatsnew/section-other.html
  (this link is expected to die, so just search for "what's new in 2.5")
- open issues in build process:
  - sed'ing out /usr/local/bin/python from files causes build to fail
    if not filtered by grep (see %%prep section) - might be a bug in sed
  - 2.3.3-dirs patch + --enable-shared + --libdir breaks build,
    because "-L/usr/lib*/python2.5/config" is added instead of "-L."
    Workaround in 2.5c1-dirs-fix, should be replaced soon
  - test_file fails in autobuild, but is OK when building manually
  - test_nis fails in autobuild, probably due to a misconfiguration
    on autobuild servers
  - it might be good to create python-sqlite3 subpackage
* Mon Apr 24 2006 jmatejek@suse.cz
- update to 2.4.3
  - no big changes, bugfix-only release (about 50 bugs fixed)
* Wed Mar 15 2006 jmatejek@suse.cz
- moved -doc and -doc-pdf into separate noarch specfile
* Mon Feb 27 2006 jmatejek@suse.cz
- implemented /usr/local path schemes for bug #149809
  - python now recognizes packages in /usr/local/lib/python2.4
  - distutils install by default into /usr/local/lib/python2.4/site-packages
  - on 64bit systems that is of course lib64
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 14 2006 kukuk@suse.de
- Add gmp-devel to nfb
* Mon Nov 28 2005 jmatejek@suse.cz
- reenabled optimization on ppc64
* Fri Nov 11 2005 nadvornik@suse.cz
- fixed another bug in canonicalize patch [#133267]
* Wed Oct  5 2005 jmatejek@suse.cz
- update to 2.4.2
- additional fixes to canonicalize patch, restored interactive mode
* Mon Sep 26 2005 jmatejek@suse.cz
- replaced the previous patch with a new one
  - it now tries to use canonical_file_name(), falling back to realpath()
    and eventually readlink
  - canonical_file_name() branch now sets the buffer length
* Fri Sep 23 2005 jmatejek@suse.cz
- fixed to build with gcc's new buffer overflow checking
  - added patch from https://bugzilla.redhat.com/bugzilla/show_bug.cgi?id=169046
* Fri Apr 22 2005 schwab@suse.de
- Always enable SSL bug workarounds.
* Tue Apr  5 2005 mcihar@suse.cz
- update to 2.4.1
* Thu Mar 24 2005 uli@suse.de
- fixed to build on ARM
* Tue Mar  1 2005 mcihar@suse.cz
- skip some test on ia64 for now
* Tue Feb  8 2005 mcihar@suse.cz
- mark configuration files as %%config
* Tue Feb  1 2005 mcihar@suse.cz
- fix vulnerability in SimpleXMLRPCServer (bug #50321, CAN-2005-0089)
* Tue Dec 28 2004 mcihar@suse.cz
- disable bsddb tests, it fails probably on all 64-bit
* Thu Dec 23 2004 mcihar@suse.cz
- make lib64 installation also work on others than x86_64
* Mon Dec 20 2004 mcihar@suse.de
- fixed build on ppc64
  - update multiarch patch
  - do not test bsddb internals
  - remove optimalisation from flags, it breaks at least math
* Mon Dec 20 2004 mcihar@suse.cz
- added extra files needed for some tests (codecmaps and unicode normalisation)
- enabled bsddb tests
- reenabled test_shelve, as it works now
* Thu Dec 16 2004 mcihar@suse.cz
- update db 4.3 patch
- fix bdist_rpm when spec file generates more than one rpm
* Tue Dec 14 2004 bg@suse.de
- disable tests for hppa
* Mon Dec  6 2004 mcihar@suse.cz
- fix bsddb module for current bsddb
- improved readline detection
* Fri Dec  3 2004 mcihar@suse.cz
- updated documentation to 2.4
* Wed Dec  1 2004 mcihar@suse.cz
- don't use wctype functions from glibc, it breaks at some situations
- enable tests during compilation, removing currently known failures
* Tue Nov 30 2004 mcihar@suse.cz
- update to 2.4 final
* Wed Nov 24 2004 mcihar@suse.cz
- yet another ignore list update, ignore man and locale dirs
* Wed Nov 24 2004 mcihar@suse.cz
- ignore /etc and avoid infinite loop while generating directory list
* Wed Nov 24 2004 mcihar@suse.cz
- ignore one more directories in file list generating
- handle correctly headers path in file list generating
- handle extra_dir in file list generating
- use same way as mandrake to support lib64, at least it's a bit cleaner
  solution than we had, so we now also have sys.lib
- audioop is now enabled on 64-bit
* Tue Nov 23 2004 mcihar@suse.cz
- updated to 2.4c1 (2.4 release candidate 1)
- dropped python-mpz package as it was dropped by upstream
- completely rewritten and much simplified rpm file list generation, if you
  have problems with new version, please drop me a note
- install also /etc/profile.d/python.csh
* Tue Aug 24 2004 mcihar@suse.cz
- updated README.SUSE
- added startup script, which enables saving of history and completion
  for interactive usage
* Thu May 27 2004 mcihar@suse.cz
- update to 2.3.4 final (no changes from rc 1)
* Wed May 19 2004 mcihar@suse.cz
- update to 2.3.4 release candidate 1 (obsoletes some patches taken from cvs)
- forcing of large file support is not needed (for quite a long time)
- updated README.SUSE
* Tue Mar 16 2004 mcihar@suse.cz
- included some fixes from cvs:
  - fix possible segfault in bsddb
  - urllib2 supports non-anonymous ftp and absolute paths
  - fixed GC problems in PyWeakref_NewRef
* Thu Mar 11 2004 mcihar@suse.cz
- fix readline with utf-8 (bug #34302)
* Wed Mar  3 2004 mcihar@suse.cz
- obsoletes python21
* Thu Feb 26 2004 mcihar@suse.cz
- all subpackages depend on current python version
* Thu Feb 19 2004 mcihar@suse.cz
- fix Lib/email/Charset.py for use in some locales
- fix format string in zipimport module
- use system readline
- add more IPV6 socket options
- use sed instead of perl for replacing
- include LICENSE
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Mon Jan  5 2004 mcihar@suse.cz
- updated to 2.3.3 (final)
- call %%{run_ldconfig} in post and postun
- libpython.2.3.so symlink moved to devel package (bug #33779)
* Fri Dec 12 2003 mcihar@suse.cz
- updated to 2.3.3 (release candidate 1)
* Tue Nov 18 2003 mcihar@suse.cz
- use wchar_t functions from libc, this reduces size of interpreter
* Mon Oct 27 2003 kukuk@suse.de
- Remove useless Requires
- Remove not used packages from neededforbuild
* Fri Oct  3 2003 mcihar@suse.cz
- updated to 2.3.2
  - A bug in autoconf that broke building on HP/UX systems is fixed.
  - A bug in the Python configure script that meant os.fsync() was
    never available is fixed.
* Thu Oct  2 2003 mcihar@suse.cz
- force use of directories passed to configure script (-dirs.patch), bug #31947
* Mon Sep 29 2003 mcihar@suse.cz
- updated to 2.3.1, most of changes were alredy included in -cvs.patch
- not so verbose untaring
* Thu Sep 11 2003 mcihar@suse.cz
- included fixes from cvs (branch release23-maint), this fixes some
  memory leaks and other bugs (-cvs.patch)
- nicer output from pydoc (-pydoc.patch)
- cleaned up configure parameters
- compiling with -Wall
* Wed Sep 10 2003 mcihar@suse.cz
- build as shared
* Wed Sep  3 2003 mcihar@suse.cz
- python now obsoletes python-nothreads (bug #29907)
* Thu Aug 14 2003 mcihar@suse.cz
- fixed symlinks to configuration files
- cleaned up spec file
* Wed Aug  6 2003 mcihar@suse.cz
- updated lib64 patch
* Tue Aug  5 2003 mcihar@suse.cz
- updated to final 2.3, some highlights:
  * Python 2.3 is about 20-30%% faster than Python 2.2.3
  * Brand new IDLE
  * Some new or upgraded built-ins, includes better support for
    unicode, new bool type...
  * Lots of upgraded or new modules and packages.
  * PYTHONINSPECT variabale that can cause python to behave as it
    was executed with -i parameter.
* Tue Jul 29 2003 ro@suse.de
- added tk-devel to neededforbuild
* Thu Jun 26 2003 mcihar@suse.cz
- updated to cvs snapshot, mostly because of finally correct DESTDIR
  support, to avoid buildroot leftovers
* Tue Jun 24 2003 mcihar@suse.cz
- better excluding site-packages from generated dirlist
* Tue Jun 17 2003 mcihar@suse.cz
- ignore site-packages and share directories for filelists
- include install dir if not site-packages in filelists
* Tue Jun 17 2003 mcihar@suse.cz
- better handle mutliple level of install directories when
  generating %%dir entries
* Mon Jun 16 2003 mcihar@suse.cz
- one more distutils patch update:
  * fix generating of dirs in chrooted installs for install_data
  * don't include directory for install_scripts
* Mon Jun 16 2003 mcihar@suse.cz
- updated patch to work around problems with self defined get_outputs
* Mon Jun 16 2003 mcihar@suse.cz
- modified distutils to allow generating complete file list for rpm
  (including directories with %%dir macro), to use this use
  - -record-rpm= instead of --record=
* Thu Jun  5 2003 mcihar@suse.cz
- move documentation where it was in 2.2 versions
- fixed permissions for some scripts in devel package
* Thu May 29 2003 mcihar@suse.cz
- cleaned up specfile
- make executable only files that should be
* Mon May 19 2003 mcihar@suse.cz
- removed .cvsignore files
* Tue Apr 29 2003 mcihar@suse.cz
- updated lib64 patch
* Mon Apr 28 2003 mcihar@suse.cz
- updated to 2.3b1, some highlights:
  - sum() builtin, adds a sequence of numbers, beats reduce().
  - csv module, reads comma-separated-value files (and more).
  - timeit module, times code snippets.
  - os.walk(), a generator slated to replace os.path.walk().
  - platform module, by Marc-Andre Lemburg, returns detailed platform
    information.
* Thu Apr 10 2003 mcihar@suse.cz
- added DEFS to config/Makefile as it was in 2.2
* Wed Apr  2 2003 mcihar@suse.cz
- updated lib64 patch
- fixed list of built modules for 64-bit arches
* Tue Apr  1 2003 mcihar@suse.cz
- updated to python 2.3 alpha 2
  - updated many builtins and modules
  - new modules: bsddb, bz2, datetime, logging, optparse, sets,
    textwrap, zipimport,
  - some general things have changed:
  - Hex/oct literals prefixed with a minus sign were handled
    inconsistently.
  - Package index and metadata for distutils.
  - Encoding declarations - you can put a comment of the form
    "# -*- coding:  -*-" in the first or second line of a Python
    source file to indicate the encoding (e.g. utf-8).
  - Import from zipfiles.
  - see Misc/NEWS in documentation or python website -
    http://python.org/2.3/highlights.html for more details
- moved distutils into -devel package
- cleaned up specfile
* Tue Apr  1 2003 mcihar@suse.cz
- removed RPM_BUILD_ROOT leftovers (bug #25963)
* Thu Mar  6 2003 kukuk@suse.de
- Provide/Obsolete python-tkinter
* Tue Jan 28 2003 mcihar@suse.cz
- idle symlink corrected for lib64
- fixed LIBDEST path for distutils, closes #22322
* Fri Jan 10 2003 mcihar@suse.cz
- fixed distutils for lib64
* Wed Dec 18 2002 mcihar@suse.cz
- improved blt detection for tkinter
- build with detected version of tix
- enabled SIGFPE catching
- enabled signal module
- enabled C++ support
* Fri Nov 29 2002 mcihar@suse.cz
- enabled ipv6 support
- no apache is needed for building
- python-nothreads is not built anymore as is seems that mod_python
  works correctly woth python 2.2.2 and threads
- Makefile also copied to config directory in rpm
* Wed Nov 27 2002 adrian@suse.de
- Makefile.pre* to config directory
  (following the official spec file change)
* Fri Nov  8 2002 mcihar@suse.cz
- fixed bad source number for suse-start-python-mode.el
* Thu Nov  7 2002 mcihar@suse.cz
- fixed %%files section for idle on lib64 arches
* Wed Nov  6 2002 mcihar@suse.cz
- included python-mode.el for emacs
- idle moved from demos to separate package
- merged tk and tkinter
* Wed Oct 30 2002 mcihar@suse.cz
- removed not needed l2h and tetex from neededforbuild
* Wed Oct 30 2002 ro@suse.de
- changed neededforbuild <l2h> to <latex2html>
* Wed Oct 23 2002 mcihar@suse.cz
- updated to 2.2.2 (bugfix release)
- moved python-korean into separate source package
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Tue Sep 10 2002 kukuk@suse.de
- Add provides for correct update
* Thu Sep  5 2002 ro@suse.de
- remove l2h from neededforbuild (apparently no longer used)
* Thu Aug 15 2002 ro@suse.de
- no fpectl.so on alpha
* Tue Aug 13 2002 uli@suse.de
- rediffed lib64 patch
* Thu Aug  8 2002 vinil@suse.de
- new version 2.2.1
- new version of Korean codes 2.0.5
  and splitted to standalone package 'python-korean'
- get rid of Makefile.pre.in
- clean part added to spec
* Sun Jul 28 2002 kukuk@suse.de
- removed termcap and tetex from neededforbuild (not used)
* Fri Jul 26 2002 adrian@suse.de
- fix neededforbuild
* Tue Jun 11 2002 meissner@suse.de
- add ppc64 to list of 64bit archs that don't compile 3 of the plugins.
* Tue Jun  4 2002 stepan@suse.de
- change more locations of lib to %%{_lib} on platforms
  that need it.
- change Makefile to use install -d instead of mkdir
  to solve trouble when installing in buildroots.
* Mon Jun  3 2002 stepan@suse.de
- Change config/Makefile and config/Makefile.pre.in
  to use %%_lib instead of lib (fixes i.e. zope)
* Fri May 17 2002 sf@suse.de
- changed site.py to detect the correct location (is needed at least for
  postresql to build
- it still needs to be corrected, as only 64-bit excutable shlibs
  have to reside in */lib64
* Wed May 15 2002 coolo@suse.de
- fixing file list for s390x
* Tue May 14 2002 ro@suse.de
- use libdir
- try to get this working with lib64
* Mon May  6 2002 schwab@suse.de
- Build python library with -fPIC, for inclusion in shared library.
* Wed Apr 17 2002 schwab@suse.de
- Fix detection of readline library (use -lncurses instead of -ltermcap).
* Sat Mar 23 2002 ro@suse.de
- changed neededforbuild <l2h> to <l2h l2h-pngicons>
* Fri Feb  1 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Wed Jan  9 2002 rvasice@suse.cz
- used correct Makefile.pre.in
* Wed Jan  9 2002 rvasice@suse.cz
- added Makefile.pre.in to enable build other python packages
* Mon Jan  7 2002 rvasice@suse.cz
- update to version 2.2
- recreated modules list
* Mon Dec 17 2001 ro@suse.de
- fixed for gmp-4.x
* Mon Sep  3 2001 rvasice@suse.cz
- added patch for Large File Support
* Mon Aug 27 2001 rvasice@suse.cz
- removed conflicting file /etc/susehelp.d/pythonhtml.conf from
  subpackage python-doc
* Fri Aug 17 2001 schwab@suse.de
- Compile python library with -fPIC to allow inclusion in shared
  libraries.
- Fix configure check for rl_completion_matches.
- Replace use of config.guess by %%ifarch.
* Mon Aug 13 2001 ro@suse.de
- added regex module (needed for yodl)
- filelist probably needs re-check
* Mon Jul 30 2001 rvasice@suse.cz
- fix /usr/local path
* Fri Jul 27 2001 rvasice@suse.cz
- update to version 2.1.1
* Tue May  8 2001 mfabian@suse.de
- bzip2 sources
* Fri Apr 13 2001 kukuk@suse.de
- fix build with new readline library
* Wed Apr 11 2001 utuerk@suse.de
- added pythonhtml.conf for susehelp
* Fri Feb 23 2001 ro@suse.de
- changed neededforbuild <apache> to <apache apache-devel>
* Fri Feb 23 2001 ro@suse.de
- added readline/readline-devel to neededforbuild (split from bash)
* Mon Jan 22 2001 kukuk@suse.de
- Use -fPIC
* Tue Jan 16 2001 schwab@suse.de
- Compile python library with -fpic so that it can be included in a
  shared library (for mod_python).
* Mon Jan 15 2001 mt@suse.de
- added uc-kr codec, thanks to Hwang, SangJin <violiet@susekorea.net>
* Sun Dec 31 2000 schwab@suse.de
- Fix filelist for ia64.
* Mon Dec 18 2000 mt@suse.de
- added sub-package python-nothreads for mod_python apache-module
- added Obsoletes for old 8.3 packages names
* Wed Dec  6 2000 mt@suse.de
- cleaned up pythons tk dependencies
* Thu Nov 30 2000 ro@suse.de
- fixed tix-link
* Wed Nov 29 2000 ro@suse.de
- changed neededforbuild <tcld> to <tcl-devel>
* Mon Nov 27 2000 mt@suse.de
- changed libnetpb to libnetpbm in neededforbuild
- changed file-list in python-devel
* Thu Nov 23 2000 mt@suse.de
- added openssl-devel to neededforbuild
* Wed Nov 22 2000 mt@suse.de
- removed site-packages from Setup.in patch
- python-64bit.patch should be used on all 64bit platforms
* Sun Nov 19 2000 mt@suse.de
- updated to BeOpen-Python-2.0
* Fri Oct 27 2000 kukuk@suse.de
- Use long filenames
- Fix some paths
- Include <db3/db_185.h>
* Thu Jul  6 2000 mt@suse.de
- added anydbm (whichdb.py) patch from www.tummy.com
* Sat May 27 2000 kukuk@suse.de
- Use libtk8.3.so and libtcl8.3.so
* Thu May  4 2000 kukuk@suse.de
- Fix filelist for new doc dir
* Tue Mar 14 2000 ro@suse.de
- fixed filelist for alpha
* Wed Mar  1 2000 werner@suse.de
- Fix config.guess selection
* Wed Feb 16 2000 uli@suse.de
- passing MANDIR to "make install libinstall" (seems like it gets
  lost somewhere)
* Wed Feb 16 2000 ro@suse.de
- man to /usr/share using macro
* Tue Feb 15 2000 mt@suse.de
- stripped the python binary
* Mon Oct 11 1999 max@suse.de
- ready for the new Tcl/Tk packages
* Mon Sep 27 1999 bs@suse.de
- fixed requirements for sub packages
* Mon Sep 20 1999 ro@suse.de
- added python_image_lib as requires to pyth_tk and as provides to pyth_tkl
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Jun  7 1999 mt@suse.de
- disabled pyth_dvi module in spec-file
* Wed May 26 1999 ro@suse.de
- added libpng to neededforbuild
* Wed May 26 1999 ro@suse.de
- added blt to neededforbuild
* Tue May 25 1999 mt@suse.de
- new version 1.5.2
- splited into sub-packages: pyth_doc, pyth_ps, pyth_pdf,
  pyth_dvi, pyth_dmo, pyth_tk, pyth_tkl, pyth_cur, pythgdbm
  to have better base-package compatibility to andrich.net.
* Thu Mar 18 1999 ro@suse.de
- don't set POSIXLY_CORRECT for second patch
* Tue Jan 19 1999 ro@suse.de
- added automake to neededforbuild
- alpha-fix: don't mix up dec-osf with linux-alpha
* Wed Dec  2 1998 mt@suse.de
- removed TkInter into a separate package - pyth_tk - to make it
  possible to replace it with a PIL based TkInter (Python Imaging
  Lib) and better package dependecies (not each app needs TkInter)
- removed Makefile.Linux - all build is done from spec file now
- more /usr/local path fixes
* Fri Nov  6 1998 ro@suse.de
- added automake to neededforbuild
- configure with threads
* Thu Nov  5 1998 ro@suse.de
- use db_185.h only for glibc-2.1
* Wed Sep 23 1998 ro@suse.de
- two hacks to compile for glibc:
  Modules/bsddbmodule.c include db_185.h for glibc
  Modules/mpzmodule.c   gmp-mparam.h dont exist for glibc / use define
* Sun Aug 23 1998 ke@suse.de
- Compress PostScript docu.
* Mon Aug 17 1998 mt@suse.de
- linked readline- and curses-modules with ncurses
* Fri Aug  7 1998 mt@suse.de
- python modules - file permissions changed (-x)
* Sat Jul 11 1998 bs@suse.de
- fixed neededforbuild
* Thu Jul  9 1998 mt@suse.de
- new revision 1.5.1
- docu in a separate package (pyth_doc)
- Tkinter uses tk8.0/tcl8.0 now
- first attempt to make it "alpha ready" (spec- & dif-file)
* Mon Mar  2 1998 ro@suse.de
- fixed dependency to /usr/local/bin/python
* Mon Feb  9 1998 ro@suse.de
- added some in neededforbuild
* Wed Feb  4 1998 mt@suse.de
- new Version 1.5 with more features, html documentation and new modules
* Mon Sep 15 1997 mt@suse.de
- added support for readline and (shared) modules: tkinter, dbm, gdbm,
  syslog, ncurses, ... - see /usr/lib/python1.4/config/Setup for details
* Thu Jun  5 1997 mt@suse.de
- new Version 1.4
- a symlink (python -> python1.4) will be used instead of a hardlink
